@@ -18,7 +18,7 @@ use Wx qw( :misc );
 use Wx::ActiveX;
 use base qw( Wx::ActiveX );
 
-our $VERSION = '0.11';
+our $VERSION = '0.13';
 
 our (@EXPORT_OK, %EXPORT_TAGS);
 $EXPORT_TAGS{everything} = \@EXPORT_OK;
@@ -191,114 +191,114 @@ sub EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION { &Wx::ActiveX::EVT_ACTI
 # Exports & Tags
 
 {
-	my @eventexports = qw(
-			EVENTID_AX_MEDIAPLAYER_ENDOFSTREAM
-			EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGREMOVED
-			EVENTID_AX_MEDIAPLAYER_DEVICESTATUSCHANGE
-			EVENTID_AX_MEDIAPLAYER_CURRENTPLAYLISTITEMAVAILABLE
-			EVENTID_AX_MEDIAPLAYER_BUFFERING
-			EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGCHANGED
-			EVENTID_AX_MEDIAPLAYER_SCRIPTCOMMAND
-			EVENTID_AX_MEDIAPLAYER_PLAYSTATECHANGE
-			EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONCHANGE
-			EVENTID_AX_MEDIAPLAYER_CURRENTMEDIAITEMAVAILABLE
-			EVENTID_AX_MEDIAPLAYER_AUDIOLANGUAGECHANGE
-			EVENTID_AX_MEDIAPLAYER_DEVICESYNCERROR
-			EVENTID_AX_MEDIAPLAYER_POSITIONCHANGE
-			EVENTID_AX_MEDIAPLAYER_MOUSEDOWN
-			EVENTID_AX_MEDIAPLAYER_DOUBLECLICK
-			EVENTID_AX_MEDIAPLAYER_OPENSTATECHANGE
-			EVENTID_AX_MEDIAPLAYER_CREATEPARTNERSHIPCOMPLETE
-			EVENTID_AX_MEDIAPLAYER_MODECHANGE
-			EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGADDED
-			EVENTID_AX_MEDIAPLAYER_KEYUP
-			EVENTID_AX_MEDIAPLAYER_DISCONNECT
-			EVENTID_AX_MEDIAPLAYER_MOUSEUP
-			EVENTID_AX_MEDIAPLAYER_STATUSCHANGE
-			EVENTID_AX_MEDIAPLAYER_CLICK
-			EVENTID_AX_MEDIAPLAYER_DEVICESYNCSTATECHANGE
-			EVENTID_AX_MEDIAPLAYER_PLAYERRECONNECT
-			EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONCHANGE
-			EVENTID_AX_MEDIAPLAYER_DURATIONUNITCHANGE
-			EVENTID_AX_MEDIAPLAYER_KEYDOWN
-			EVENTID_AX_MEDIAPLAYER_KEYPRESS
-			EVENTID_AX_MEDIAPLAYER_OPENPLAYLISTSWITCH
-			EVENTID_AX_MEDIAPLAYER_DEVICEDISCONNECT
-			EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTSETASDELETED
-			EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTREMOVED
-			EVENTID_AX_MEDIAPLAYER_MEDIAERROR
-			EVENTID_AX_MEDIAPLAYER_WARNING
-			EVENTID_AX_MEDIAPLAYER_CURRENTPLAYLISTCHANGE
-			EVENTID_AX_MEDIAPLAYER_MARKERHIT
-			EVENTID_AX_MEDIAPLAYER_SWITCHEDTOCONTROL
-			EVENTID_AX_MEDIAPLAYER_CDROMMEDIACHANGE
-			EVENTID_AX_MEDIAPLAYER_CURRENTITEMCHANGE
-			EVENTID_AX_MEDIAPLAYER_DEVICECONNECT
-			EVENTID_AX_MEDIAPLAYER_MOUSEMOVE
-			EVENTID_AX_MEDIAPLAYER_MEDIACHANGE
-			EVENTID_AX_MEDIAPLAYER_ERROR
-			EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTADDED
-			EVENTID_AX_MEDIAPLAYER_PLAYERDOCKEDSTATECHANGE
-			EVENTID_AX_MEDIAPLAYER_PLAYLISTCHANGE
-			EVENTID_AX_MEDIAPLAYER_NEWSTREAM
-			EVENTID_AX_MEDIAPLAYER_DOMAINCHANGE
-			EVENTID_AX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION
-			EVT_ACTIVEX_MEDIAPLAYER_ENDOFSTREAM
-			EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGREMOVED
-			EVT_ACTIVEX_MEDIAPLAYER_DEVICESTATUSCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTITEMAVAILABLE
-			EVT_ACTIVEX_MEDIAPLAYER_BUFFERING
-			EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGCHANGED
-			EVT_ACTIVEX_MEDIAPLAYER_SCRIPTCOMMAND
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYSTATECHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_CURRENTMEDIAITEMAVAILABLE
-			EVT_ACTIVEX_MEDIAPLAYER_AUDIOLANGUAGECHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCERROR
-			EVT_ACTIVEX_MEDIAPLAYER_POSITIONCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_MOUSEDOWN
-			EVT_ACTIVEX_MEDIAPLAYER_DOUBLECLICK
-			EVT_ACTIVEX_MEDIAPLAYER_OPENSTATECHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_CREATEPARTNERSHIPCOMPLETE
-			EVT_ACTIVEX_MEDIAPLAYER_MODECHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGADDED
-			EVT_ACTIVEX_MEDIAPLAYER_KEYUP
-			EVT_ACTIVEX_MEDIAPLAYER_DISCONNECT
-			EVT_ACTIVEX_MEDIAPLAYER_MOUSEUP
-			EVT_ACTIVEX_MEDIAPLAYER_STATUSCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_CLICK
-			EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCSTATECHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYERRECONNECT
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_DURATIONUNITCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_KEYDOWN
-			EVT_ACTIVEX_MEDIAPLAYER_KEYPRESS
-			EVT_ACTIVEX_MEDIAPLAYER_OPENPLAYLISTSWITCH
-			EVT_ACTIVEX_MEDIAPLAYER_DEVICEDISCONNECT
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTSETASDELETED
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTREMOVED
-			EVT_ACTIVEX_MEDIAPLAYER_MEDIAERROR
-			EVT_ACTIVEX_MEDIAPLAYER_WARNING
-			EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_MARKERHIT
-			EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOCONTROL
-			EVT_ACTIVEX_MEDIAPLAYER_CDROMMEDIACHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_CURRENTITEMCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_DEVICECONNECT
-			EVT_ACTIVEX_MEDIAPLAYER_MOUSEMOVE
-			EVT_ACTIVEX_MEDIAPLAYER_MEDIACHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_ERROR
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTADDED
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYERDOCKEDSTATECHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_NEWSTREAM
-			EVT_ACTIVEX_MEDIAPLAYER_DOMAINCHANGE
-			EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION
-	);
+    my @eventexports = qw(
+            EVENTID_AX_MEDIAPLAYER_ENDOFSTREAM
+            EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGREMOVED
+            EVENTID_AX_MEDIAPLAYER_DEVICESTATUSCHANGE
+            EVENTID_AX_MEDIAPLAYER_CURRENTPLAYLISTITEMAVAILABLE
+            EVENTID_AX_MEDIAPLAYER_BUFFERING
+            EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGCHANGED
+            EVENTID_AX_MEDIAPLAYER_SCRIPTCOMMAND
+            EVENTID_AX_MEDIAPLAYER_PLAYSTATECHANGE
+            EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONCHANGE
+            EVENTID_AX_MEDIAPLAYER_CURRENTMEDIAITEMAVAILABLE
+            EVENTID_AX_MEDIAPLAYER_AUDIOLANGUAGECHANGE
+            EVENTID_AX_MEDIAPLAYER_DEVICESYNCERROR
+            EVENTID_AX_MEDIAPLAYER_POSITIONCHANGE
+            EVENTID_AX_MEDIAPLAYER_MOUSEDOWN
+            EVENTID_AX_MEDIAPLAYER_DOUBLECLICK
+            EVENTID_AX_MEDIAPLAYER_OPENSTATECHANGE
+            EVENTID_AX_MEDIAPLAYER_CREATEPARTNERSHIPCOMPLETE
+            EVENTID_AX_MEDIAPLAYER_MODECHANGE
+            EVENTID_AX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGADDED
+            EVENTID_AX_MEDIAPLAYER_KEYUP
+            EVENTID_AX_MEDIAPLAYER_DISCONNECT
+            EVENTID_AX_MEDIAPLAYER_MOUSEUP
+            EVENTID_AX_MEDIAPLAYER_STATUSCHANGE
+            EVENTID_AX_MEDIAPLAYER_CLICK
+            EVENTID_AX_MEDIAPLAYER_DEVICESYNCSTATECHANGE
+            EVENTID_AX_MEDIAPLAYER_PLAYERRECONNECT
+            EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONCHANGE
+            EVENTID_AX_MEDIAPLAYER_DURATIONUNITCHANGE
+            EVENTID_AX_MEDIAPLAYER_KEYDOWN
+            EVENTID_AX_MEDIAPLAYER_KEYPRESS
+            EVENTID_AX_MEDIAPLAYER_OPENPLAYLISTSWITCH
+            EVENTID_AX_MEDIAPLAYER_DEVICEDISCONNECT
+            EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTSETASDELETED
+            EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTREMOVED
+            EVENTID_AX_MEDIAPLAYER_MEDIAERROR
+            EVENTID_AX_MEDIAPLAYER_WARNING
+            EVENTID_AX_MEDIAPLAYER_CURRENTPLAYLISTCHANGE
+            EVENTID_AX_MEDIAPLAYER_MARKERHIT
+            EVENTID_AX_MEDIAPLAYER_SWITCHEDTOCONTROL
+            EVENTID_AX_MEDIAPLAYER_CDROMMEDIACHANGE
+            EVENTID_AX_MEDIAPLAYER_CURRENTITEMCHANGE
+            EVENTID_AX_MEDIAPLAYER_DEVICECONNECT
+            EVENTID_AX_MEDIAPLAYER_MOUSEMOVE
+            EVENTID_AX_MEDIAPLAYER_MEDIACHANGE
+            EVENTID_AX_MEDIAPLAYER_ERROR
+            EVENTID_AX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTADDED
+            EVENTID_AX_MEDIAPLAYER_PLAYERDOCKEDSTATECHANGE
+            EVENTID_AX_MEDIAPLAYER_PLAYLISTCHANGE
+            EVENTID_AX_MEDIAPLAYER_NEWSTREAM
+            EVENTID_AX_MEDIAPLAYER_DOMAINCHANGE
+            EVENTID_AX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION
+            EVT_ACTIVEX_MEDIAPLAYER_ENDOFSTREAM
+            EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGREMOVED
+            EVT_ACTIVEX_MEDIAPLAYER_DEVICESTATUSCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTITEMAVAILABLE
+            EVT_ACTIVEX_MEDIAPLAYER_BUFFERING
+            EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGCHANGED
+            EVT_ACTIVEX_MEDIAPLAYER_SCRIPTCOMMAND
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYSTATECHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_CURRENTMEDIAITEMAVAILABLE
+            EVT_ACTIVEX_MEDIAPLAYER_AUDIOLANGUAGECHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCERROR
+            EVT_ACTIVEX_MEDIAPLAYER_POSITIONCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_MOUSEDOWN
+            EVT_ACTIVEX_MEDIAPLAYER_DOUBLECLICK
+            EVT_ACTIVEX_MEDIAPLAYER_OPENSTATECHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_CREATEPARTNERSHIPCOMPLETE
+            EVT_ACTIVEX_MEDIAPLAYER_MODECHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGADDED
+            EVT_ACTIVEX_MEDIAPLAYER_KEYUP
+            EVT_ACTIVEX_MEDIAPLAYER_DISCONNECT
+            EVT_ACTIVEX_MEDIAPLAYER_MOUSEUP
+            EVT_ACTIVEX_MEDIAPLAYER_STATUSCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_CLICK
+            EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCSTATECHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYERRECONNECT
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_DURATIONUNITCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_KEYDOWN
+            EVT_ACTIVEX_MEDIAPLAYER_KEYPRESS
+            EVT_ACTIVEX_MEDIAPLAYER_OPENPLAYLISTSWITCH
+            EVT_ACTIVEX_MEDIAPLAYER_DEVICEDISCONNECT
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTSETASDELETED
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTREMOVED
+            EVT_ACTIVEX_MEDIAPLAYER_MEDIAERROR
+            EVT_ACTIVEX_MEDIAPLAYER_WARNING
+            EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_MARKERHIT
+            EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOCONTROL
+            EVT_ACTIVEX_MEDIAPLAYER_CDROMMEDIACHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_CURRENTITEMCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_DEVICECONNECT
+            EVT_ACTIVEX_MEDIAPLAYER_MOUSEMOVE
+            EVT_ACTIVEX_MEDIAPLAYER_MEDIACHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_ERROR
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTADDED
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYERDOCKEDSTATECHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_NEWSTREAM
+            EVT_ACTIVEX_MEDIAPLAYER_DOMAINCHANGE
+            EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION
+    );
 
-	$EXPORT_TAGS{"mediaplayer"} = [] if not exists $EXPORT_TAGS{"mediaplayer"};
-	push @EXPORT_OK, ( @eventexports ) ;
-	push @{ $EXPORT_TAGS{"mediaplayer"} }, ( @eventexports );
+    $EXPORT_TAGS{"mediaplayer"} = [] if not exists $EXPORT_TAGS{"mediaplayer"};
+    push @EXPORT_OK, ( @eventexports ) ;
+    push @{ $EXPORT_TAGS{"mediaplayer"} }, ( @eventexports );
 }
 
 
@@ -349,6 +349,15 @@ Wx::ActiveX::WMPlayer - interface to WMPlayer.OCX ActiveX Control
     my $activex = Wx::ActiveX::WMPlayer->newVersion( 1, $parent );
     
     EVT_ACTIVEX_MEDIAPLAYER_OPENSTATECHANGE( $handler, $activex, \&on_event_openstatechange );
+    
+    use Win32::OLE;
+    
+    my $filename = 'c:/path/to/mediafile';
+    
+    $activex->PropSet( 'URL', $filename);
+    my $winole = $activex->GetOLE;
+    $winole->controls->play; 
+    
 
 =head1 DESCRIPTION
 
@@ -397,57 +406,57 @@ WMPlayer.OCX.4
 
 The module provides the following exportable event subs
 
-	EVT_ACTIVEX_MEDIAPLAYER_OPENSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_STATUSCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_AUDIOLANGUAGECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_ENDOFSTREAM( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_POSITIONCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MARKERHIT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DURATIONUNITCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_SCRIPTCOMMAND( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DISCONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_BUFFERING( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_NEWSTREAM( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_ERROR( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_WARNING( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CDROMMEDIACHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MEDIACHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CURRENTMEDIAITEMAVAILABLE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTITEMAVAILABLE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CURRENTITEMCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGADDED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGREMOVED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTADDED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTREMOVED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTSETASDELETED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MODECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGCHANGED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MEDIAERROR( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DOMAINCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_OPENPLAYLISTSWITCH( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOCONTROL( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYERDOCKEDSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_PLAYERRECONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CLICK( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DOUBLECLICK( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_KEYDOWN( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_KEYPRESS( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_KEYUP( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MOUSEDOWN( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MOUSEMOVE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_MOUSEUP( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DEVICECONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DEVICEDISCONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DEVICESTATUSCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCERROR( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
-	EVT_ACTIVEX_MEDIAPLAYER_CREATEPARTNERSHIPCOMPLETE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_OPENSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_STATUSCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_AUDIOLANGUAGECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_ENDOFSTREAM( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_POSITIONCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MARKERHIT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DURATIONUNITCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_SCRIPTCOMMAND( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DISCONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_BUFFERING( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_NEWSTREAM( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_ERROR( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_WARNING( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CDROMMEDIACHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MEDIACHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CURRENTMEDIAITEMAVAILABLE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CURRENTPLAYLISTITEMAVAILABLE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CURRENTITEMCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGADDED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGREMOVED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTADDED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTREMOVED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYLISTCOLLECTIONPLAYLISTSETASDELETED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MODECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MEDIACOLLECTIONATTRIBUTESTRINGCHANGED( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MEDIAERROR( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DOMAINCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_OPENPLAYLISTSWITCH( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOPLAYERAPPLICATION( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_SWITCHEDTOCONTROL( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYERDOCKEDSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_PLAYERRECONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CLICK( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DOUBLECLICK( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_KEYDOWN( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_KEYPRESS( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_KEYUP( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MOUSEDOWN( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MOUSEMOVE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_MOUSEUP( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DEVICECONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DEVICEDISCONNECT( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DEVICESTATUSCHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCSTATECHANGE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_DEVICESYNCERROR( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
+    EVT_ACTIVEX_MEDIAPLAYER_CREATEPARTNERSHIPCOMPLETE( $evthandler, $activexcontrol, \&on_event_mediaplayer_sub );
 
 
 =head1 ACTIVEX INFO
